==> jc-1.4.0.tar.gz: javax/crypto/spec/PBEParameterSpec.h <==
// public class javax.crypto.spec.PBEParameterSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3caf4ba5d9723ea3 javax_crypto_spec_PBEParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_PBEParameterSpec_H_
#define _JC_javax_crypto_spec_PBEParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$sub_refs	_jc_javax_crypto_spec_PBEParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_PBEParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$refs	_jc_javax_crypto_spec_PBEParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$nonrefs	_jc_javax_crypto_spec_PBEParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$object	_jc_javax_crypto_spec_PBEParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_PBEParameterSpec$vmethods	_jc_javax_crypto_spec_PBEParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_PBEParameterSpec$vtable	_jc_javax_crypto_spec_PBEParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_PBEParameterSpec$vtype	_jc_javax_crypto_spec_PBEParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_PBEParameterSpec$method$_init$6b9b44bc28d43597(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *, struct _jc_byte_array *, jint);

// Virtual methods
extern jint _jc_javax_crypto_spec_PBEParameterSpec$method$getIterationCount$c84099ed1055b2b4(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *);
extern _jc_byte_array *_jc_javax_crypto_spec_PBEParameterSpec$method$getSalt$d47caba1a97e2fb5(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_PBEParameterSpec$method_info$getIterationCount$c84099ed1055b2b4;
extern _jc_method _jc_javax_crypto_spec_PBEParameterSpec$method_info$getSalt$d47caba1a97e2fb5;

// Virtual methods structure
struct _jc_javax_crypto_spec_PBEParameterSpec$vmethods {
	jint	(*getIterationCount$c84099ed1055b2b4)(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *);
	_jc_byte_array	*(*getSalt$d47caba1a97e2fb5)(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_PBEParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_PBEParameterSpec$vmethods	javax_crypto_spec_PBEParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_PBEParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_PBEParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_PBEParameterSpec$sub_refs {
	_jc_byte_array	*salt;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_PBEParameterSpec$refs {
    _jc_javax_crypto_spec_PBEParameterSpec$sub_refs	javax_crypto_spec_PBEParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_PBEParameterSpec$sub_nonrefs {
	jint	iterationCount;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_PBEParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_PBEParameterSpec$sub_nonrefs	javax_crypto_spec_PBEParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_PBEParameterSpec$object {
	_jc_javax_crypto_spec_PBEParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_PBEParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_PBEParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_PBEParameterSpec$vtype _jc_javax_crypto_spec_PBEParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_PBEParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_PBEParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_PBEParameterSpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/PBEParameterSpec.h <==
// public class javax.crypto.spec.PBEParameterSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3caf4ba5d9723ea3 javax_crypto_spec_PBEParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_PBEParameterSpec_H_
#define _JC_javax_crypto_spec_PBEParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$sub_refs	_jc_javax_crypto_spec_PBEParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_PBEParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$refs	_jc_javax_crypto_spec_PBEParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$nonrefs	_jc_javax_crypto_spec_PBEParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_PBEParameterSpec$object	_jc_javax_crypto_spec_PBEParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_PBEParameterSpec$vmethods	_jc_javax_crypto_spec_PBEParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_PBEParameterSpec$vtable	_jc_javax_crypto_spec_PBEParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_PBEParameterSpec$vtype	_jc_javax_crypto_spec_PBEParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_PBEParameterSpec$method$_init$6b9b44bc28d43597(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_crypto_spec_PBEParameterSpec$method$getIterationCount$c84099ed1055b2b4(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_javax_crypto_spec_PBEParameterSpec$method$getSalt$d47caba1a97e2fb5(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_PBEParameterSpec$method_info$getIterationCount$c84099ed1055b2b4;
extern _jc_method _jc_javax_crypto_spec_PBEParameterSpec$method_info$getSalt$d47caba1a97e2fb5;

// Virtual methods structure
struct _jc_javax_crypto_spec_PBEParameterSpec$vmethods {
	jint	(*getIterationCount$c84099ed1055b2b4)(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getSalt$d47caba1a97e2fb5)(_jc_env *, struct _jc_javax_crypto_spec_PBEParameterSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_PBEParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_PBEParameterSpec$vmethods	javax_crypto_spec_PBEParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_PBEParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_PBEParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_PBEParameterSpec$sub_refs {
	_jc_byte_array	*salt;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_PBEParameterSpec$refs {
    _jc_javax_crypto_spec_PBEParameterSpec$sub_refs	javax_crypto_spec_PBEParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_PBEParameterSpec$sub_nonrefs {
	jint	iterationCount;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_PBEParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_PBEParameterSpec$sub_nonrefs	javax_crypto_spec_PBEParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_PBEParameterSpec$object {
	_jc_javax_crypto_spec_PBEParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_PBEParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_PBEParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_PBEParameterSpec$vtype _jc_javax_crypto_spec_PBEParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_PBEParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_PBEParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_PBEParameterSpec_H_ */
